@@ -681,8 +681,8 @@ class SnowflakeSourceConnector(C8Connector):
             ConfigProperty('primary_key', 'Unique Primary Key (to be used as _key for the collection)', ConfigAttributeType.STRING, False, False,
                            description='A unique primary key from the snowflake table which needs be used as _key for the collection.'
                                        ' If the columns does not have any column with unique values then do not specify anything here,'
-                                       ' _key for the collection will be autogenerated in this case.',
-                           placeholder_value='my_db.my_schema.my_table'),
+                                       ' _key for the collection will be autogenerated in this case. Primary key is case sensitive.',
+                           placeholder_value='my_primary_key'),
             ConfigProperty('role', 'Role',
                            ConfigAttributeType.STRING, False, False,
                            description='Snowflake role to use.',
